@@ -23,7 +23,10 @@
 #include "libimportwizard_export.h"
 
 #include <KAssistantDialog>
-
+namespace LibImportWizard {
+class AbstractImporter;
+class AbstractDisplayInfo;
+}
 class KPageWidgetItem;
 class SelectProgramPage;
 class SelectComponentPage;
@@ -33,19 +36,17 @@ class ImportSettingPage;
 class ImportAddressbookPage;
 class ImportFinishPage;
 class ImportCalendarPage;
-class AbstractImporter;
 class ManualSelectFilterPage;
 class ManualImportMailPage;
 
-namespace Akonadi
-{
+namespace Akonadi {
 class Collection;
 }
 class LIBIMPORTWIZARD_EXPORT ImportWizard : public KAssistantDialog
 {
     Q_OBJECT
 public:
-    enum WizardMode {
+    enum class WizardMode {
         AutoDetect = 0,
         Manual = 1
     };
@@ -53,9 +54,9 @@ public:
     explicit ImportWizard(WizardMode mode, QWidget *parent = nullptr);
     ~ImportWizard();
 
-    void next() Q_DECL_OVERRIDE;
-    void reject() Q_DECL_OVERRIDE;
-    void back() Q_DECL_OVERRIDE;
+    void next() override;
+    void reject() override;
+    void back() override;
 
     ImportMailPage *importMailPage() const;
     ImportFilterPage *importFilterPage() const;
@@ -64,9 +65,6 @@ public:
     ImportFinishPage *importFinishPage() const;
     ImportCalendarPage *importCalendarPage() const;
 
-    void addFinishInfo(const QString &log);
-    void addFinishError(const QString &log);
-
 private Q_SLOTS:
     void slotProgramSelected(const QString &program);
     void slotImportMailsClicked();
@@ -80,21 +78,24 @@ private Q_SLOTS:
     void slotCollectionChanged(const Akonadi::Collection &selectedCollection);
 
 private:
+    void addFinishInfo(const QString &log);
+    void addFinishError(const QString &log);
+
     void readConfig();
     void writeConfig();
     void initializeImportModule();
     void createAutomaticModePage();
-    void addImportModule(AbstractImporter *);
+    void addImportModule(LibImportWizard::AbstractImporter *);
     void checkModules();
-    void setAppropriatePage(AbstractImporter::TypeSupportedOptions options);
+    void setAppropriatePage(LibImportWizard::AbstractImporter::TypeSupportedOptions options);
     void enableAllImportButton();
     void createManualModePage();
     void updatePagesFromMode();
 
-    QMap<QString, AbstractImporter *> mlistImport;
+    QMap<QString, LibImportWizard::AbstractImporter *> mlistImport;
 
     WizardMode mMode;
-    AbstractImporter *mSelectedPim;
+    LibImportWizard::AbstractImporter *mSelectedPim;
 
     KPageWidgetItem *mSelectProgramPageItem;
     KPageWidgetItem *mSelectComponentPageItem;
@@ -118,7 +119,8 @@ private:
     ManualImportMailPage *mImportpage;
     KPageWidgetItem *mSelfilterpageItem;
     KPageWidgetItem *mImportpageItem;
+
+    LibImportWizard::AbstractDisplayInfo *mAbstractDisplayInfo;
 };
 
 #endif /* IMPORTWIZARD_H */
-
